@@ -102,6 +102,8 @@ elif os.name == "posix":
         expr = os.fsencode(r'[^\(\)\s]*lib%s\.[^\(\)\s]*' % re.escape(name))
 
         c_compiler = shutil.which('gcc')
+        if not c_compiler:
+            c_compiler = shutil.which('clang')
         if not c_compiler:
             c_compiler = shutil.which('cc')
         if not c_compiler:
@@ -110,7 +112,7 @@ elif os.name == "posix":
 
         temp = tempfile.NamedTemporaryFile()
         try:
-            args = [c_compiler, '-Wl,-R/usr/pkg/lib', '-L/usr/pkg/lib', '-Wl,-t', '-o', temp.name, '-l' + name]
+            args = [c_compiler, '-Wl,-R/usr/pkg/lib', '-L/usr/pkg/lib', '-Wl,-R/usr/X11R7/lib', '-L/usr/X11R7/lib', '-Wl,-t', '-o', temp.name, '-l' + name]
 
             env = dict(os.environ)
             env['LC_ALL'] = 'C'
